SI-Score (Synthetic Interventions on Scenes for Robustness Evaluation) is a
dataset to evaluate robustness of image classification models to changes in
object size, location and rotation angle.

In SI-SCORE, we take objects and backgrounds and systematically vary object
size, location and rotation angle so we can study the effect of changing these
factors on model performance. The image label space is the ImageNet
label space (1k classes) for easy evaluation of models.

More information about the dataset can be found at
https://github.com/google-research/si-score.